Security Advisories (1)
CPANSA-Valiant-2024-001

closed potential security issue with deeply nested paramters in the DBIC glue code. This was a hack that could let someone create a child record if you were allowing find_by_unique rather than find by primary key.

NAME

Valiant::Util::Exception::InvalidValidatorArgs - Args passed to a Validator are invalid

SYNOPSIS

throw_exception InvalidValidatorArgs => (args=>$args);

DESCRIPTION

A non categorized exception

ATTRIBUTES

args

Arguments actually passed

SEE ALSO

Valiant

AUTHOR

See Valiant

COPYRIGHT & LICENSE

See Valiant